<div class="left">
    <?php  echo $this->callElement("default/common/quicklinks"); ?>
</div>
<div class="center-large">
    <?php
    /*
     * Message display Section
     */
    echo $this->get_tag("h2",NULL,"Member Registration");
    echo $this->get_tag("p",$this->get_tag("span",array("class"=>"message"),""));

    /* Right column */
    echo $this->get_tag("form",array("method"=>"post","class"=>"form","id"=>"signup_form","action"=> $this->baseurl("/member/signup")));
        echo $this->get_tag("ul");
            echo App::Load("Helper/Html")->get_from_row($this->__("First Name"),App::Load("Helper/Html")->inputTag("data[Member][f_name]","",array("class"=>"input check_notempty",'id'=>'f_name','longdesc'=>'Please enter your first name')) );
            echo App::Load("Helper/Html")->get_from_row($this->__("Last Name"),App::Load("Helper/Html")->inputTag("data[Member][l_name]","",array("class"=>"input check_notempty",'id'=>'l_name','longdesc'=>'Please enter your last name')) );
            echo App::Load("Helper/Html")->get_from_row($this->__("Country"), App::Load("Helper/Html")->countryTag("data[Member][country]","",array("title"=>"Country","id" => "country","class"=>"select check_notempty"),array('title'=>'Your Country','longdesc'=>'Please select your country')) );
            echo App::Load("Helper/Html")->get_from_row($this->__("Address"),App::Load("Helper/Html")->textareaTag("data[Member][address]","",array("rows"=>"3","class"=>"input check_notempty",'id'=>'address','longdesc'=>'Enter your address infomration')) );
            echo App::Load("Helper/Html")->get_from_row($this->__("Email "),App::Load("Helper/Html")->inputTag("data[Member][email]","",array("class"=>"input check_email",'id'=>'email')) );
            echo App::Load("Helper/Html")->get_from_row($this->__("Password"),App::Load("Helper/Html")->passwordTag("data[Member][password]","",array("class"=>"input check_notempty",'id'=>'login_password','longdesc'=>'Enter a password')) );
            echo App::Load("Helper/Html")->get_from_row($this->__("Confirm Password"),App::Load("Helper/Html")->passwordTag("data[Member][clogin_password]","",array("title"=>"Confirmed Password","class"=>"input check_notempty",'id'=>'clogin_password','longdesc'=>'Repeat your password')) );
            echo App::Load("Helper/Html")->get_from_row($this->__("About you"),App::Load("Helper/Html")->textareaTag("data[Member][note]","",array("rows"=>"6","class"=>"input check_notempty",'id'=>'note','longdesc'=>'Please enter at least 200 characters to describe you.')),NULL,'Write a brif about you' );
            echo App::Load("Helper/Html")->get_from_row(App::Helper('Html')->capachaTag("memberregi",Array("bk_color"=>"#99011E","font_color"=>"#FFFFFF")),App::Load("Helper/Html")->inputTag("data[Member][capacha]","",array("title"=>"Confirmed Password","class"=>"input check_notdefault",'id'=>'capachs','longdesc'=>'Please type text correctly, display on left side image')) );
            echo App::Load("Helper/Html")->get_from_row("&nbsp;",App::Load("Helper/Html")->submitTag("data[Member][submit]","Register Me",array("class" => "button")) );
        echo $this->get_tag("/ul");
    echo $this->get_tag("/form");
     App::Helper('JavaScript')->setAjax(array("debug"=>false,"autoHide"=>true))->appForm('#signup_form');
    ?>
</div>